% author: Swit
% date: 2021/09/24
% project: mathexercise.cls
% usage: Class file to write exercise solutions

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{mathexercise}[2021/09/24 class file to write mathematical exercise solutions]
\LoadClassWithOptions{report}
% 加载常用宏包
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsthm}
\RequirePackage{xcolor}
\RequirePackage[heading=true]{ctex}
\RequirePackage[shortlabels]{enumitem}
\RequirePackage{tcolorbox}
% 章标题定制
\ctexset {
chapter = {
beforeskip = 0pt,
fixskip = true,
format = \Huge\bfseries,
nameformat = \rule{\linewidth}{1bp}\par\bigskip\hfill\chapternamebox,
number = \arabic{chapter},
aftername = \par\medskip,
aftertitle = \par\bigskip\nointerlineskip\rule{\linewidth}{2bp}\par
}
}
\newcommand\chapternamebox[1]{%
\parbox{\ccwd}{\linespread{1}\selectfont\centering #1}}


% 中文设置
\setCJKmainfont[BoldFont=FandolHei,ItalicFont=FandolKai]{FandolSong}


%%% 定义常用命令
% Roman Font
\newcommand{\e}{\mathrm{e}}
\newcommand{\T}{\mathrm{T}}
\newcommand{\ii}{\mathrm{i}}
% Differential Operator(在多种实现方法之中，个人认为此方法最佳)
\newcommand{\diff}{\mathop{}\!\mathrm{d}}
% Declare Math Operator
\DeclareMathOperator{\sgn}{sgn}
\DeclareMathOperator{\codim}{codim}
\DeclareMathOperator{\diam}{diam} % diameter
\DeclareMathOperator{\spt}{spt} % support set
\DeclareMathOperator{\conv}{conv}
% Real and Imaginary part of complex numbers
\renewcommand{\Re}{\operatorname{Re}}
\renewcommand{\Im}{\operatorname{Im}}
% Number set
\newcommand\FR{\mathbb{R}}
\newcommand\FC{\mathbb{C}}
\newcommand\FK{\mathbb{K}}
\newcommand\FN{\mathbb{N}}
\newcommand\FZ{\mathbb{Z}}

\newcommand\Rn{\mathbb{R}^n}
\newcommand{\lrangle}[2]{\langle#1,#2\rangle}

%proof environment and solve environment
\makeatletter
\renewenvironment{proof}{\par
	\pushQED{\qed}%
	\normalfont\topsep1\p@\@plus6\p@\relax
	\trivlist
	\item\relax
	{\hspace*{\parindent}{\heiti 证明}\@addpunct{:}}\hspace\labelsep\ignorespaces
}{%
	\popQED\endtrivlist\@endpefalse
}
\makeatother

\makeatletter
\newenvironment{solve}{\par
	\pushQED{\qed}%
	\normalfont\topsep1\p@\@plus6\p@\relax
	\trivlist
	\item\relax
	{\hspace*{\parindent}{\heiti 解}\@addpunct{:}}\hspace\labelsep\ignorespaces
}{%
	\popQED\endtrivlist\@endpefalse
}
\makeatother

%theorem environment
\newtheoremstyle{mytheorem}
                {3pt}
				{3pt}
				{\rmfamily}
				{\parindent}
				{\bfseries}
				{}
				{.5em}{\thmname{#1}\thmnumber{ #2}\thmnote{ (#3)}}
\theoremstyle{mytheorem}\newtheorem{theorem}{定理}
\theoremstyle{mytheorem}\newtheorem{lemma}{引理}
\theoremstyle{mytheorem}\newtheorem{example}{例}
\theoremstyle{mytheorem}\newtheorem*{remark}{注}

% 定制列表
\setlist{nosep,left=\parindent}

%%% Exercise counter
\newcounter{chapexer}[chapter]
\newcounter{secexer}[section]
\setcounter{chapexer}{0}
\setcounter{secexer}{0}

%%% Exercise environment
\DeclareOption{withinchap}{%
    \newenvironment{exercise}%
	               {\refstepcounter{chapexer}\par\textbf{\thechapexer.}}%
				   {\par\ignorespacesafterend}}
\DeclareOption{withsec}{%
	\newenvironment{exercise}%
				   {\refstepcounter{secexer}\par\textbf{\thechapexer.}}%
				   {\par\ignorespacesafterend}}
\ExecuteOptions{withinchap}
\ProcessOptions\relax

%---------tasks--------
\RequirePackage{tasks}
\settasks{after-item-skip=0.5ex plus 0.5ex minus 1ex}
\NewTasksEnvironment[label={(\arabic*)}, item-indent=4em, label-offset=1em]{exer}[\item](2)
\NewTasksEnvironment[label={(\arabic*)}, item-indent=4em, label-offset=1em]{exer3}[\item](3)

% hyperref
\RequirePackage{hyperref}
\hypersetup{
    colorlinks,%
    linkcolor=red,%
    pdfauthor=Swit
}

% titlepage

\renewcommand{\maketitle}{%
    \makeatletter
    \begin{titlepage}
    \begin{center}
    \Huge\bfseries\@title 
    \end{center}
    \vspace{3cm}
    \begin{center}
    \@author
    \end{center}    
    \end{titlepage}
    \makeatother} 